==> oauth2-oidc-sdk-8.4-sources.jar: com/nimbusds/oauth2/sdk/as/AuthorizationServerConfigurationRequest.java <==
/*
 * oauth2-oidc-sdk
 *
 * Copyright 2012-2016, Connect2id Ltd and contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed
 * under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.nimbusds.oauth2.sdk.as;


import java.net.URI;

import net.jcip.annotations.Immutable;

import com.nimbusds.oauth2.sdk.AbstractConfigurationRequest;
import com.nimbusds.oauth2.sdk.id.Issuer;


/**
 * OAuth 2.0 Authorisation Server (AS) configuration request.
 *
 * <p>Example HTTP request:
 *
 * <pre>
 * GET /.well-known/oauth-authorization-server HTTP/1.1
 * Host: example.com
 * </pre>
 *
 * <p>Related specifications:
 *
 * <ul>
 *     <li>OAuth 2.0 Authorization Server Metadata (RFC 8414)
 * </ul>
 */
@Immutable
public class AuthorizationServerConfigurationRequest extends AbstractConfigurationRequest {
	
	
	/**
	 * The well-known path for OAuth 2.0 Authorisation Server metadata.
	 */
	public static final String OAUTH_SERVER_WELL_KNOWN_PATH = "/.well-known/oauth-authorization-server";
	
	
	/**
	 * Creates a new OAuth 2.0 Authorisation Server configuration request.
	 *
	 * @param issuer The issuer. Must represent a valid URL.
	 */
	public AuthorizationServerConfigurationRequest(final Issuer issuer) {
		super(URI.create(issuer.getValue()), OAUTH_SERVER_WELL_KNOWN_PATH);
	}
}

==> oauth2-oidc-sdk-9.19-sources.jar: com/nimbusds/oauth2/sdk/as/AuthorizationServerConfigurationRequest.java <==
/*
 * oauth2-oidc-sdk
 *
 * Copyright 2012-2016, Connect2id Ltd and contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use
 * this file except in compliance with the License. You may obtain a copy of the
 * License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed
 * under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.nimbusds.oauth2.sdk.as;


import java.net.URI;

import net.jcip.annotations.Immutable;

import com.nimbusds.oauth2.sdk.AbstractConfigurationRequest;
import com.nimbusds.oauth2.sdk.WellKnownPathComposeStrategy;
import com.nimbusds.oauth2.sdk.id.Issuer;


/**
 * OAuth 2.0 Authorisation Server (AS) configuration request.
 *
 * <p>Example HTTP request:
 *
 * <pre>
 * GET /.well-known/oauth-authorization-server HTTP/1.1
 * Host: example.com
 * </pre>
 *
 * <p>Related specifications:
 *
 * <ul>
 *     <li>OAuth 2.0 Authorization Server Metadata (RFC 8414)
 * </ul>
 */
@Immutable
public class AuthorizationServerConfigurationRequest extends AbstractConfigurationRequest {
	
	
	/**
	 * The well-known path for OAuth 2.0 Authorisation Server metadata.
	 */
	public static final String OAUTH_SERVER_WELL_KNOWN_PATH = "/.well-known/oauth-authorization-server";
	
	
	/**
	 * Creates a new OAuth 2.0 Authorisation Server configuration request
	 * using the {@link WellKnownPathComposeStrategy#POSTFIX postfix
	 * well-known path composition strategy}.
	 *
	 * @param issuer The issuer. Must represent a valid URL.
	 */
	public AuthorizationServerConfigurationRequest(final Issuer issuer) {
		this(issuer, WellKnownPathComposeStrategy.POSTFIX);
	}
	
	
	/**
	 * Creates a new OAuth 2.0 Authorisation Server configuration request.
	 *
	 * @param issuer   The issuer. Must represent a valid URL.
	 * @param strategy The well-known path composition strategy. Must not
	 *                 be {@code null}.
	 */
	public AuthorizationServerConfigurationRequest(final Issuer issuer, final WellKnownPathComposeStrategy strategy) {
		super(URI.create(issuer.getValue()), OAUTH_SERVER_WELL_KNOWN_PATH, strategy);
	}
}
